@@ -55,8 +55,17 @@ func newApp() *cobra.Command {
 		SilenceUsage:  true,
 		SilenceErrors: true,
 	}
+	rootCmd.PersistentFlags().String("log-level", "", "Set the logging level [trace, debug, info, warn, error]")
 	rootCmd.PersistentFlags().Bool("debug", false, "debug mode")
 	rootCmd.PersistentPreRunE = func(cmd *cobra.Command, args []string) error {
+		l, _ := cmd.Flags().GetString("log-level")
+		if l != "" {
+			lvl, err := logrus.ParseLevel(l)
+			if err != nil {
+				return err
+			}
+			logrus.SetLevel(lvl)
+		}
 		debug, _ := cmd.Flags().GetBool("debug")
 		if debug {
 			logrus.SetLevel(logrus.DebugLevel)
@@ -119,3 +128,19 @@ func handleExitCoder(err error) {
 		return
 	}
 }
+
+// WrapArgsError annotates cobra args error with some context, so the error message is more user-friendly
+func WrapArgsError(argFn cobra.PositionalArgs) cobra.PositionalArgs {
+	return func(cmd *cobra.Command, args []string) error {
+		err := argFn(cmd, args)
+		if err == nil {
+			return nil
+		}
+
+		return fmt.Errorf("%q %s.\nSee '%s --help'.\n\nUsage:  %s\n\n%s",
+			cmd.CommandPath(), err.Error(),
+			cmd.CommandPath(),
+			cmd.UseLine(), cmd.Short,
+		)
+	}
+}
