@@ -33,10 +33,10 @@ Hint: try --debug to show the detailed logs, if it seems hanging (mostly due to
 
 func newShellCommand() *cobra.Command {
 	var shellCmd = &cobra.Command{
-		Use:               "shell INSTANCE [COMMAND...]",
+		Use:               "shell [flags] INSTANCE [COMMAND...]",
 		Short:             "Execute shell in Lima",
 		Long:              shellHelp,
-		Args:              cobra.MinimumNArgs(1),
+		Args:              WrapArgsError(cobra.MinimumNArgs(1)),
 		RunE:              shellAction,
 		ValidArgsFunction: shellBashComplete,
 		SilenceErrors:     true,
