@@ -32,7 +32,7 @@ $ limactl sudoers --check /etc/sudoers.d/lima
 The content is written to stdout, NOT to the file.
 This command must not run as the root.
 See %s for the usage.`, networksMD),
-		Args: cobra.MaximumNArgs(1),
+		Args: WrapArgsError(cobra.MaximumNArgs(1)),
 		RunE: sudoersAction,
 	}
 	configFile, _ := networks.ConfigFile()
