@@ -1,12 +1,15 @@
 package downloader
 
 import (
+	"bytes"
 	"crypto/sha256"
 	"errors"
 	"fmt"
 	"io"
 	"net/http"
 	"os"
+	"os/exec"
+	"path"
 	"path/filepath"
 	"strings"
 	"time"
@@ -38,6 +41,8 @@ type Result struct {
 
 type options struct {
 	cacheDir       string // default: empty (disables caching)
+	decompress     bool   // default: false (keep compression)
+	description    string // default: url
 	expectedDigest digest.Digest
 }
 
@@ -64,6 +69,22 @@ func WithCacheDir(cacheDir string) Opt {
 	}
 }
 
+// WithDecription adds a user description of the download.
+func WithDescription(description string) Opt {
+	return func(o *options) error {
+		o.description = description
+		return nil
+	}
+}
+
+// WithDecompress decompress the download from the cache.
+func WithDecompress(decompress bool) Opt {
+	return func(o *options) error {
+		o.decompress = decompress
+		return nil
+	}
+}
+
 // WithExpectedDigest is used to validate the downloaded file against the expected digest.
 //
 // The digest is not verified in the following cases:
@@ -133,8 +154,9 @@ func Download(local, remote string, opts ...Opt) (*Result, error) {
 		}
 	}
 
+	ext := path.Ext(remote)
 	if IsLocal(remote) {
-		if err := copyLocal(localPath, remote, o.expectedDigest); err != nil {
+		if err := copyLocal(localPath, remote, ext, o.decompress, o.description, o.expectedDigest); err != nil {
 			return nil, err
 		}
 		res := &Result{
@@ -145,7 +167,7 @@ func Download(local, remote string, opts ...Opt) (*Result, error) {
 	}
 
 	if o.cacheDir == "" {
-		if err := downloadHTTP(localPath, remote, o.expectedDigest); err != nil {
+		if err := downloadHTTP(localPath, remote, o.description, o.expectedDigest); err != nil {
 			return nil, err
 		}
 		res := &Result{
@@ -174,11 +196,11 @@ func Download(local, remote string, opts ...Opt) (*Result, error) {
 			if o.expectedDigest.String() != shadDigestS {
 				return nil, fmt.Errorf("expected digest %q does not match the cached digest %q", o.expectedDigest.String(), shadDigestS)
 			}
-			if err := copyLocal(localPath, shadData, ""); err != nil {
+			if err := copyLocal(localPath, shadData, ext, o.decompress, "", ""); err != nil {
 				return nil, err
 			}
 		} else {
-			if err := copyLocal(localPath, shadData, o.expectedDigest); err != nil {
+			if err := copyLocal(localPath, shadData, ext, o.decompress, o.description, o.expectedDigest); err != nil {
 				return nil, err
 			}
 		}
@@ -199,11 +221,11 @@ func Download(local, remote string, opts ...Opt) (*Result, error) {
 	if err := os.WriteFile(shadURL, []byte(remote), 0644); err != nil {
 		return nil, err
 	}
-	if err := downloadHTTP(shadData, remote, o.expectedDigest); err != nil {
+	if err := downloadHTTP(shadData, remote, o.description, o.expectedDigest); err != nil {
 		return nil, err
 	}
 	// no need to pass the digest to copyLocal(), as we already verified the digest
-	if err := copyLocal(localPath, shadData, ""); err != nil {
+	if err := copyLocal(localPath, shadData, ext, o.decompress, "", ""); err != nil {
 		return nil, err
 	}
 	if shadDigest != "" && o.expectedDigest != "" {
@@ -244,7 +266,7 @@ func canonicalLocalPath(s string) (string, error) {
 	return localpathutil.Expand(s)
 }
 
-func copyLocal(dst, src string, expectedDigest digest.Digest) error {
+func copyLocal(dst, src, ext string, decompress bool, description string, expectedDigest digest.Digest) error {
 	srcPath, err := canonicalLocalPath(src)
 	if err != nil {
 		return err
@@ -262,9 +284,63 @@ func copyLocal(dst, src string, expectedDigest digest.Digest) error {
 	if err != nil {
 		return err
 	}
+	if description != "" {
+		// TODO: progress bar for copy
+	}
+	if _, ok := Decompressor(ext); ok && decompress {
+		return decompressLocal(dstPath, srcPath, ext)
+	}
 	return fs.CopyFile(dstPath, srcPath)
 }
 
+func Decompressor(ext string) ([]string, bool) {
+	var program string
+	switch ext {
+	case ".gz":
+		program = "gzip"
+	case ".bz2":
+		program = "bzip2"
+	case ".xz":
+		program = "xz"
+	case ".zst":
+		program = "zstd"
+	default:
+		return nil, false
+	}
+	// -d --decompress
+	return []string{program, "-d"}, true
+}
+
+func decompressLocal(dst, src, ext string) error {
+	command, found := Decompressor(ext)
+	if !found {
+		return fmt.Errorf("decompressLocal: unknown extension %s", ext)
+	}
+	logrus.Infof("decompressing %s with %v", ext, command)
+	in, err := os.Open(src)
+	if err != nil {
+		return err
+	}
+	defer in.Close()
+	out, err := os.OpenFile(dst, os.O_CREATE|os.O_WRONLY, 0644)
+	if err != nil {
+		return err
+	}
+	defer out.Close()
+	buf := new(bytes.Buffer)
+	cmd := exec.Command(command[0], command[1:]...)
+	cmd.Stdin = in
+	cmd.Stdout = out
+	cmd.Stderr = buf
+	err = cmd.Run()
+	if err != nil {
+		if ee, ok := err.(*exec.ExitError); ok {
+			ee.Stderr = buf.Bytes()
+		}
+	}
+	return err
+}
+
 func validateLocalFileDigest(localPath string, expectedDigest digest.Digest) error {
 	if localPath == "" {
 		return fmt.Errorf("validateLocalFileDigest: got empty localPath")
@@ -316,7 +392,7 @@ func createBar(size int64) (*pb.ProgressBar, error) {
 	return bar, nil
 }
 
-func downloadHTTP(localPath, url string, expectedDigest digest.Digest) error {
+func downloadHTTP(localPath, url string, description string, expectedDigest digest.Digest) error {
 	if localPath == "" {
 		return fmt.Errorf("downloadHTTP: got empty localPath")
 	}
@@ -357,6 +433,12 @@ func downloadHTTP(localPath, url string, expectedDigest digest.Digest) error {
 	}
 	multiWriter := io.MultiWriter(writers...)
 
+	if !HideProgress {
+		if description == "" {
+			description = url
+		}
+		fmt.Printf("Downloading %s\n", description)
+	}
 	bar.Start()
 	if _, err := io.Copy(multiWriter, bar.NewProxyReader(resp.Body)); err != nil {
 		return err
