@@ -50,12 +50,12 @@ func EnsureDisk(cfg Config) error {
 		var ensuredBaseDisk bool
 		errs := make([]error, len(cfg.LimaYAML.Images))
 		for i, f := range cfg.LimaYAML.Images {
-			if err := fileutils.DownloadFile(baseDisk, f.File, "the image", *cfg.LimaYAML.Arch); err != nil {
+			if _, err := fileutils.DownloadFile(baseDisk, f.File, true, "the image", *cfg.LimaYAML.Arch); err != nil {
 				errs[i] = err
 				continue
 			}
 			if f.Kernel != nil {
-				if err := fileutils.DownloadFile(kernel, f.Kernel.File, "the kernel", *cfg.LimaYAML.Arch); err != nil {
+				if _, err := fileutils.DownloadFile(kernel, f.Kernel.File, false, "the kernel", *cfg.LimaYAML.Arch); err != nil {
 					errs[i] = err
 					continue
 				}
@@ -67,7 +67,7 @@ func EnsureDisk(cfg Config) error {
 				}
 			}
 			if f.Initrd != nil {
-				if err := fileutils.DownloadFile(initrd, *f.Initrd, "the initrd", *cfg.LimaYAML.Arch); err != nil {
+				if _, err := fileutils.DownloadFile(initrd, *f.Initrd, false, "the initrd", *cfg.LimaYAML.Arch); err != nil {
 					errs[i] = err
 					continue
 				}
@@ -76,8 +76,7 @@ func EnsureDisk(cfg Config) error {
 			break
 		}
 		if !ensuredBaseDisk {
-			return fmt.Errorf("failed to download the image, attempted %d candidates, errors=%v",
-				len(cfg.LimaYAML.Images), errs)
+			return fileutils.Errors(errs)
 		}
 	}
 	diskSize, _ := units.RAMInBytes(*cfg.LimaYAML.Disk)
@@ -104,14 +103,14 @@ func EnsureDisk(cfg Config) error {
 	return nil
 }
 
-func CreateDataDisk(dir string, size int) error {
+func CreateDataDisk(dir, format string, size int) error {
 	dataDisk := filepath.Join(dir, filenames.DataDisk)
 	if _, err := os.Stat(dataDisk); err == nil || !errors.Is(err, fs.ErrNotExist) {
 		// datadisk already exists
 		return err
 	}
 
-	args := []string{"create", "-f", "qcow2", dataDisk, strconv.Itoa(size)}
+	args := []string{"create", "-f", format, dataDisk, strconv.Itoa(size)}
 	cmd := exec.Command("qemu-img", args...)
 	if out, err := cmd.CombinedOutput(); err != nil {
 		return fmt.Errorf("failed to run %v: %q: %w", cmd.Args, string(out), err)
@@ -357,7 +356,16 @@ func Cmdline(cfg Config) (string, []string, error) {
 
 	// CPU
 	cpu := y.CPUType[*y.Arch]
+	if runtime.GOOS == "darwin" && runtime.GOARCH == "amd64" {
+		switch {
+		case strings.HasPrefix(cpu, "host"), strings.HasPrefix(cpu, "max"):
+			if !strings.Contains(cpu, ",-pdpe1gb") {
+				logrus.Warnf("On Intel Mac, CPU type %q typically needs \",-pdpe1gb\" option (https://stackoverflow.com/a/72863744/5167443)", cpu)
+			}
+		}
+	}
 	args = appendArgsIfNoConflict(args, "-cpu", cpu)
+
 	switch *y.Arch {
 	case limayaml.X8664:
 		if strings.HasPrefix(cpu, "qemu64") && runtime.GOOS != "windows" {
