@@ -4,12 +4,15 @@ import (
 	"context"
 	"errors"
 	"fmt"
+	"io"
 	"os"
+	"os/user"
 	"path/filepath"
 	"runtime"
 	"strconv"
 	"strings"
 	"syscall"
+	"text/tabwriter"
 	"text/template"
 	"time"
 
@@ -18,6 +21,7 @@ import (
 	"github.com/lima-vm/lima/pkg/limayaml"
 	"github.com/lima-vm/lima/pkg/store/dirnames"
 	"github.com/lima-vm/lima/pkg/store/filenames"
+	"github.com/lima-vm/lima/pkg/textutil"
 )
 
 type Status = string
@@ -43,9 +47,11 @@ type Instance struct {
 	AdditionalDisks []limayaml.Disk    `json:"additionalDisks,omitempty"`
 	Networks        []limayaml.Network `json:"network,omitempty"`
 	SSHLocalPort    int                `json:"sshLocalPort,omitempty"`
+	SSHConfigFile   string             `json:"sshConfigFile,omitempty"`
 	HostAgentPID    int                `json:"hostAgentPID,omitempty"`
 	DriverPID       int                `json:"driverPID,omitempty"`
 	Errors          []error            `json:"errors,omitempty"`
+	Config          *limayaml.LimaYAML `json:"config,omitempty"`
 }
 
 func (inst *Instance) LoadYAML() (*limayaml.LimaYAML, error) {
@@ -79,6 +85,7 @@ func Inspect(instName string) (*Instance, error) {
 		inst.Errors = append(inst.Errors, err)
 		return inst, nil
 	}
+	inst.Config = y
 	inst.Arch = *y.Arch
 	inst.VMType = *y.VMType
 	inst.CPUType = y.CPUType[*y.Arch]
@@ -95,6 +102,7 @@ func Inspect(instName string) (*Instance, error) {
 	inst.AdditionalDisks = y.AdditionalDisks
 	inst.Networks = y.Networks
 	inst.SSHLocalPort = *y.SSH.LocalPort // maybe 0
+	inst.SSHConfigFile = filepath.Join(instDir, filenames.SSHConfig)
 
 	inst.HostAgentPID, err = ReadPIDFile(filepath.Join(instDir, filenames.HostAgentPID))
 	if err != nil {
@@ -205,6 +213,11 @@ type FormatData struct {
 	IdentityFile string
 }
 
+var FormatHelp = "\n" +
+	"These functions are available to go templates:\n\n" +
+	textutil.IndentString(2,
+		strings.Join(textutil.FuncHelp, "\n")+"\n")
+
 func AddGlobalFields(inst *Instance) (FormatData, error) {
 	var data FormatData
 	data.Instance = *inst
@@ -225,3 +238,140 @@ func AddGlobalFields(inst *Instance) (FormatData, error) {
 	}
 	return data, nil
 }
+
+type PrintOptions struct {
+	AllFields     bool
+	TerminalWidth int
+}
+
+// PrintInstances prints instances in a requested format to a given io.Writer.
+// Supported formats are "json", "yaml", "table", or a go template
+func PrintInstances(w io.Writer, instances []*Instance, format string, options *PrintOptions) error {
+	switch format {
+	case "json":
+		format = "{{json .}}"
+	case "yaml":
+		format = "{{yaml .}}"
+	case "table":
+		types := map[string]int{}
+		archs := map[string]int{}
+		for _, instance := range instances {
+			types[instance.VMType]++
+			archs[instance.Arch]++
+		}
+		all := options != nil && options.AllFields
+		width := 0
+		if options != nil {
+			width = options.TerminalWidth
+		}
+		columnWidth := 8
+		hideType := false
+		hideArch := false
+		hideDir := false
+
+		columns := 1 // NAME
+		columns += 2 // STATUS
+		columns += 2 // SSH
+		// can we still fit the remaining columns (7)
+		if width == 0 || (columns+7)*columnWidth > width && !all {
+			hideType = len(types) == 1
+		}
+		if !hideType {
+			columns++ // VMTYPE
+		}
+		// only hide arch if it is the same as the host arch
+		goarch := limayaml.NewArch(runtime.GOARCH)
+		// can we still fit the remaining columns (6)
+		if width == 0 || (columns+6)*columnWidth > width && !all {
+			hideArch = len(archs) == 1 && instances[0].Arch == goarch
+		}
+		if !hideArch {
+			columns++ // ARCH
+		}
+		columns++ // CPUS
+		columns++ // MEMORY
+		columns++ // DISK
+		// can we still fit the remaining columns (2)
+		if width != 0 && (columns+2)*columnWidth > width && !all {
+			hideDir = true
+		}
+		if !hideDir {
+			columns += 2 // DIR
+		}
+		_ = columns
+
+		w := tabwriter.NewWriter(w, 4, 8, 4, ' ', 0)
+		fmt.Fprint(w, "NAME\tSTATUS\tSSH")
+		if !hideType {
+			fmt.Fprint(w, "\tVMTYPE")
+		}
+		if !hideArch {
+			fmt.Fprint(w, "\tARCH")
+		}
+		fmt.Fprint(w, "\tCPUS\tMEMORY\tDISK")
+		if !hideDir {
+			fmt.Fprint(w, "\tDIR")
+		}
+		fmt.Fprintln(w)
+
+		u, err := user.Current()
+		if err != nil {
+			return err
+		}
+		homeDir := u.HomeDir
+
+		for _, instance := range instances {
+			dir := instance.Dir
+			if strings.HasPrefix(dir, homeDir) {
+				dir = strings.Replace(dir, homeDir, "~", 1)
+			}
+			fmt.Fprintf(w, "%s\t%s\t%s",
+				instance.Name,
+				instance.Status,
+				fmt.Sprintf("127.0.0.1:%d", instance.SSHLocalPort),
+			)
+			if !hideType {
+				fmt.Fprintf(w, "\t%s",
+					instance.VMType,
+				)
+			}
+			if !hideArch {
+				fmt.Fprintf(w, "\t%s",
+					instance.Arch,
+				)
+			}
+			fmt.Fprintf(w, "\t%d\t%s\t%s",
+				instance.CPUs,
+				units.BytesSize(float64(instance.Memory)),
+				units.BytesSize(float64(instance.Disk)),
+			)
+			if !hideDir {
+				fmt.Fprintf(w, "\t%s",
+					dir,
+				)
+			}
+			fmt.Fprint(w, "\n")
+
+		}
+		return w.Flush()
+	default:
+		// NOP
+	}
+	tmpl, err := template.New("format").Funcs(textutil.TemplateFuncMap).Parse(format)
+	if err != nil {
+		return fmt.Errorf("invalid go template: %w", err)
+	}
+	for _, instance := range instances {
+		data, err := AddGlobalFields(instance)
+		if err != nil {
+			return err
+		}
+		data.Message = strings.TrimSuffix(instance.Message, "\n")
+		err = tmpl.Execute(w, data)
+		if err != nil {
+			return err
+		}
+		fmt.Fprintln(w)
+	}
+	return nil
+}
