@@ -11,6 +11,8 @@ import (
 	"os"
 	"path/filepath"
 	"strconv"
+	"strings"
+	"sync"
 	"syscall"
 
 	"github.com/Code-Hex/vz/v3"
@@ -21,11 +23,18 @@ import (
 	"github.com/lima-vm/lima/pkg/localpathutil"
 	"github.com/lima-vm/lima/pkg/networks"
 	"github.com/lima-vm/lima/pkg/qemu/imgutil"
+	"github.com/lima-vm/lima/pkg/store"
 	"github.com/lima-vm/lima/pkg/store/filenames"
 	"github.com/sirupsen/logrus"
 )
 
-func startVM(ctx context.Context, driver *driver.BaseDriver) (*vz.VirtualMachine, chan error, error) {
+type virtualMachineWrapper struct {
+	*vz.VirtualMachine
+	mu      sync.Mutex
+	stopped bool
+}
+
+func startVM(ctx context.Context, driver *driver.BaseDriver) (*virtualMachineWrapper, chan error, error) {
 	server, client, err := createSockPair()
 	if err != nil {
 		return nil, nil, err
@@ -53,6 +62,8 @@ func startVM(ctx context.Context, driver *driver.BaseDriver) (*vz.VirtualMachine
 		return nil, nil, err
 	}
 
+	wrapper := &virtualMachineWrapper{VirtualMachine: machine, stopped: false}
+
 	errCh := make(chan error)
 	go func() {
 		//Handle errors via errCh and handle stop vm during context close
@@ -81,6 +92,9 @@ func startVM(ctx context.Context, driver *driver.BaseDriver) (*vz.VirtualMachine
 					logrus.Info("[VZ] - vm state change: running")
 				case vz.VirtualMachineStateStopped:
 					logrus.Info("[VZ] - vm state change: stopped")
+					wrapper.mu.Lock()
+					wrapper.stopped = true
+					wrapper.mu.Unlock()
 					errCh <- errors.New("vz driver state stopped")
 				default:
 					logrus.Debugf("[VZ] - vm state change: %q", newState)
@@ -89,7 +103,7 @@ func startVM(ctx context.Context, driver *driver.BaseDriver) (*vz.VirtualMachine
 		}
 	}()
 
-	return machine, errCh, err
+	return wrapper, errCh, err
 }
 
 func createVM(driver *driver.BaseDriver, networkConn *os.File) (*vz.VirtualMachine, error) {
@@ -334,6 +348,66 @@ func attachDisks(driver *driver.BaseDriver, vmConfig *vz.VirtualMachineConfigura
 	}
 	configurations = append(configurations, diffDisk)
 
+	for _, diskName := range driver.Yaml.AdditionalDisks {
+		d, err := store.InspectDisk(diskName)
+		if err != nil {
+			return fmt.Errorf("failed to run load disk %q: %q", diskName, err)
+		}
+
+		if d.Instance != "" {
+			return fmt.Errorf("failed to run attach disk %q, in use by instance %q", diskName, d.Instance)
+		}
+		logrus.Infof("Mounting disk %q on %q", diskName, d.MountPoint)
+		err = d.Lock(driver.Instance.Dir)
+		if err != nil {
+			return fmt.Errorf("failed to run lock disk %q: %q", diskName, err)
+		}
+		extraDiskPath := filepath.Join(d.Dir, filenames.DataDisk)
+
+		extraDiskFormat, err := imgutil.DetectFormat(extraDiskPath)
+		if err != nil {
+			return fmt.Errorf("failed to run detect disk format %q: %q", diskName, err)
+		}
+		if extraDiskFormat != "raw" {
+			if strings.Contains(extraDiskFormat, string(os.PathSeparator)) {
+				return fmt.Errorf(
+					"failed to convert disk %q to raw for vz driver because extraDiskFormat %q contains a path separator %q",
+					diskName,
+					extraDiskFormat,
+					os.PathSeparator,
+				)
+			}
+			rawPath := fmt.Sprintf("%s.raw", extraDiskPath)
+			oldFormatPath := fmt.Sprintf("%s.%s", extraDiskPath, extraDiskFormat)
+			if err = imgutil.ConvertToRaw(extraDiskPath, rawPath); err != nil {
+				return fmt.Errorf("failed to convert %s disk %q to raw for vz driver: %w", extraDiskFormat, diskName, err)
+			}
+			if err = os.Rename(extraDiskPath, oldFormatPath); err != nil {
+				return fmt.Errorf("failed to rename additional disk for vz driver: %w", err)
+			}
+			if err = os.Rename(rawPath, extraDiskPath); err != nil {
+				return fmt.Errorf("failed to rename additional disk for vz driver: %w", err)
+			}
+			if err = os.Remove(oldFormatPath); err != nil {
+				logrus.Errorf("Failed to delete unused qcow2 additional disk %q."+
+					"Disk is no longer needed by Lima and it can be removed manually.", oldFormatPath)
+			}
+		}
+
+		if err = validateDiskFormat(extraDiskPath); err != nil {
+			return fmt.Errorf("failed to validate extra disk %q: %w", extraDiskPath, err)
+		}
+		extraDiskPathAttachment, err := vz.NewDiskImageStorageDeviceAttachmentWithCacheAndSync(extraDiskPath, false, vz.DiskImageCachingModeAutomatic, vz.DiskImageSynchronizationModeFsync)
+		if err != nil {
+			return fmt.Errorf("failed to create disk attachment for extra disk %q: %w", extraDiskPath, err)
+		}
+		extraDisk, err := vz.NewVirtioBlockDeviceConfiguration(extraDiskPathAttachment)
+		if err != nil {
+			return fmt.Errorf("failed to create new virtio block device config for extra disk %q: %w", extraDiskPath, err)
+		}
+		configurations = append(configurations, extraDisk)
+	}
+
 	if err = validateDiskFormat(ciDataPath); err != nil {
 		return err
 	}
@@ -404,7 +478,7 @@ func attachFolderMounts(driver *driver.BaseDriver, vmConfig *vz.VirtualMachineCo
 		}
 	}
 
-	if driver.Yaml.Rosetta.Enabled {
+	if *driver.Yaml.Rosetta.Enabled {
 		logrus.Info("Setting up Rosetta share")
 		directorySharingDeviceConfig, err := createRosettaDirectoryShareConfiguration()
 		if err != nil {
