@@ -26,7 +26,7 @@ const Enabled = true
 type LimaVzDriver struct {
 	*driver.BaseDriver
 
-	machine *vz.VirtualMachine
+	machine *virtualMachineWrapper
 }
 
 func New(driver *driver.BaseDriver) *LimaVzDriver {
@@ -64,6 +64,7 @@ func (l *LimaVzDriver) Validate() error {
 		"PropagateProxyEnv",
 		"CACertificates",
 		"Rosetta",
+		"AdditionalDisks",
 	); len(unknown) > 0 {
 		logrus.Warnf("Ignoring: vmType %s: %+v", *l.Yaml.VMType, unknown)
 	}
@@ -137,7 +138,10 @@ func (l *LimaVzDriver) Stop(_ context.Context) error {
 			case <-timeout:
 				return errors.New("vz timeout while waiting for stop status")
 			case <-tick:
-				if l.machine.State() == vz.VirtualMachineStateStopped {
+				l.machine.mu.Lock()
+				stopped := l.machine.stopped
+				l.machine.mu.Unlock()
+				if stopped {
 					return nil
 				}
 			}
